@@ -1,15 +1,17 @@
-"""Command-line interface for the Hubspot client."""
+"""
+Command-line interface for the Hubspot client
+"""
 import json
 import sys
 import types
-from fire.core import Fire as fire, _Fire as fire_execute
-from fire.helputils import UsageString as build_usage_string
-from fire.parser import SeparateFlagArgs as separate_flag_args
 from functools import wraps
+from typing import Callable, Dict, List, Tuple
+from fire.core import Fire as fire, _Fire as fire_execute
+from fire.helptext import HelpText as build_usage_string
+from fire.parser import SeparateFlagArgs as separate_flag_args
 from hubspot3 import Hubspot3
 from hubspot3.base import BaseClient
 from hubspot3.leads import LeadsClient
-from typing import Callable, Dict, List, Tuple
 
 
 def get_config_from_file(filename: str) -> Dict:
@@ -18,25 +20,22 @@ def get_config_from_file(filename: str) -> Dict:
         config = json.load(file)
     if not isinstance(config, dict):
         raise RuntimeError(
-            'Config file content must be an object, got "{}" instead.'.format(
-                type(config).__name__
-            )
+            f'Config file content must be an object, got "{type(config).__name__}" instead.'
         )
     return config
 
 
-class Hubspot3CLIWrapper:  # pylint: disable=empty-docstring
-    __doc__ = """
+class Hubspot3CLIWrapper:
+    hubspot3_cli_flags = build_usage_string(Hubspot3).split("\n")[-1]
+    __doc__ = f"""
         Hubspot3 CLI
 
         To get a list of supported operations, call this CLI without the "--help" option.
 
         The API client can be configured by providing options BEFORE specifying the operation to
         execute. KWARGS are:
-        [--config CONFIG_FILE_PATH] {}
-    """.format(
-        build_usage_string(Hubspot3).split("\n")[-1]
-    )
+        [--config CONFIG_FILE_PATH] {hubspot3_cli_flags}
+    """
 
     # Properties to ignore during discovery. The "me" property must be ignored
     # as it would already perform an API request while being discovered and the
@@ -91,7 +90,7 @@ class Hubspot3CLIWrapper:  # pylint: disable=empty-docstring
         return clients
 
 
-class ClientCLIWrapper:  # pylint: disable=empty-docstring
+class ClientCLIWrapper:
     __doc__ = Hubspot3CLIWrapper.__doc__
 
     # Mapping (client class to attribute names) to define methods that should
@@ -113,7 +112,7 @@ class ClientCLIWrapper:  # pylint: disable=empty-docstring
         return self._methods  # Let Fire only discover the API methods.
 
     def __str__(self):
-        return "Hubspot3 {} CLI".format(self._client_name)
+        return f"Hubspot3 {self._client_name} CLI"
 
     def _discover_methods(self, client: BaseClient) -> Dict[str, types.MethodType]:
         """Find all API methods on the given client object."""
@@ -160,10 +159,9 @@ class ClientCLIWrapper:  # pylint: disable=empty-docstring
                 "Supported ARGS/KWARGS are:",
                 build_usage_string(method),
                 "",
-                'The token "{}" may be used as an argument value, which will cause JSON data to be '
-                "read from stdin and used as the actual argument value.".format(
-                    self.STDIN_TOKEN
-                ),
+                f'The token "{self.STDIN_TOKEN}" may be used as an argument'
+                " value, which will cause JSON data to be "
+                "read from stdin and used as the actual argument value.",
             )
         )
 
