@@ -1,9 +1,9 @@
 """
 hubspot companies properties api
 """
+from typing import List, Optional, Union
 from hubspot3.base import BaseClient
 from hubspot3.utils import get_log
-from typing import List, Optional, Union
 
 
 COMPANIES_PROPERTIES_API_VERSION = "1"
@@ -21,12 +21,10 @@ class CompaniesPropertiesClient(BaseClient):
         self.log = get_log("hubspot3.companies_properties")
 
     def _get_path(self, subpath: str) -> str:
-        return "properties/v{}/companies/{}".format(
-            COMPANIES_PROPERTIES_API_VERSION, subpath
-        )
+        return f"properties/v{COMPANIES_PROPERTIES_API_VERSION}/companies/{subpath}"
 
     def get_all_companies_properties(
-        self, extra_properties: Union[str, List] = None, **options
+        self, extra_properties: Union[str, List, None] = None, **options
     ) -> Optional[List]:
         """
         Retrieve all of the company properties, including their definition, for a given account.
