@@ -2,11 +2,10 @@
 hubspot contacts api
 """
 import warnings
-from typing import Union
+from typing import Dict, List, Optional, Union
 from hubspot3.crm_associations import CRMAssociationsClient
 from hubspot3.base import BaseClient
 from hubspot3.utils import prettify, get_log
-from typing import Dict, List
 
 
 CONTACTS_API_VERSION = "1"
@@ -31,43 +30,35 @@ class ContactsClient(BaseClient):
 
     def _get_path(self, subpath: str) -> str:
         """get path"""
-        return "contacts/v{}/{}".format(CONTACTS_API_VERSION, subpath)
+        return f"contacts/v{CONTACTS_API_VERSION}/{subpath}"
 
     def get_by_id(self, contact_id: str, **options):
         """Get contact specified by ID"""
-        return self._call(
-            "contact/vid/{}/profile".format(contact_id), method="GET", **options
-        )
+        return self._call(f"contact/vid/{contact_id}/profile", method="GET", **options)
 
     def get_by_email(self, email: str, **options):
         """Get contact specified by email address."""
-        return self._call(
-            "contact/email/{email}/profile".format(email=email), method="GET", **options
-        )
+        return self._call(f"contact/email/{email}/profile", method="GET", **options)
 
-    def create(self, data: Dict = None, **options):
+    def create(self, data: Optional[Dict] = None, **options):
         """create a contact"""
         data = data or {}
         return self._call("contact", data=data, method="POST", **options)
 
-    def create_or_update_by_email(self, email: str, data: Dict = None, **options):
+    def create_or_update_by_email(
+        self, email: str, data: Optional[Dict] = None, **options
+    ):
         """Create or Updates a client with the supplied data."""
         data = data or {}
         return self._call(
-            "contact/createOrUpdate/email/{email}".format(email=email),
-            data=data,
-            method="POST",
-            **options
+            f"contact/createOrUpdate/email/{email}", data=data, method="POST", **options
         )
 
-    def update_by_id(self, contact_id: str, data: Dict = None, **options):
+    def update_by_id(self, contact_id: str, data: Optional[Dict] = None, **options):
         """Update the contact by contact_id with the given data."""
         data = data or {}
         return self._call(
-            "contact/vid/{contact_id}/profile".format(contact_id=contact_id),
-            data=data,
-            method="POST",
-            **options
+            f"contact/vid/{contact_id}/profile", data=data, method="POST", **options
         )
 
     def update_by_email(self, email: str, data=None, **options):
@@ -75,29 +66,19 @@ class ContactsClient(BaseClient):
         data = data or {}
 
         return self._call(
-            "contact/email/{}/profile".format(email),
-            data=data,
-            method="POST",
-            **options
+            f"contact/email/{email}/profile", data=data, method="POST", **options
         )
 
     def delete_by_id(self, contact_id: str, **options):
         """Delete a contact by contact_id."""
-        return self._call(
-            "contact/vid/{contact_id}".format(contact_id=contact_id),
-            method="DELETE",
-            **options
-        )
+        return self._call(f"contact/vid/{contact_id}", method="DELETE", **options)
 
     def merge(self, primary_id: int, secondary_id: int, **options):
         """merge the data from the secondary_id into the data of the primary_id"""
         data = dict(vidToMerge=secondary_id)
 
         self._call(
-            "contact/merge-vids/{}/".format(primary_id),
-            data=data,
-            method="POST",
-            **options
+            f"contact/merge-vids/{primary_id}/", data=data, method="POST", **options
         )
 
     default_batch_properties = [
@@ -114,7 +95,7 @@ class ContactsClient(BaseClient):
         "associatedcompanyid",
     ]
 
-    def get_batch(self, ids, extra_properties: Union[list, str] = None):
+    def get_batch(self, ids, extra_properties: Union[List, str, None] = None):
         """given a batch of vids, get more of their info"""
         # default properties to fetch
         properties = set(self.default_batch_properties)
@@ -141,10 +122,10 @@ class ContactsClient(BaseClient):
 
     def get_all(
         self,
-        extra_properties: Union[list, str] = None,
+        extra_properties: Union[List, str, None] = None,
         limit: int = -1,
         list_id: str = "all",
-        **options
+        **options,
     ) -> List[Dict]:
         """
         get all contacts in hubspot, fetching additional properties if passed in
@@ -161,10 +142,10 @@ class ContactsClient(BaseClient):
             query_limit = limit
         while not finished:
             batch = self._call(
-                "lists/{}/contacts/all".format(list_id),
+                f"lists/{list_id}/contacts/all",
                 method="GET",
                 params={"count": query_limit, "vidOffset": offset},
-                **options
+                **options,
             )
             output.extend(
                 self.get_batch(
@@ -183,7 +164,7 @@ class ContactsClient(BaseClient):
         limit: int = 100,
         vid_offset: int = 0,
         time_offset: int = 0,
-        **options
+        **options,
     ) -> List[Dict]:
         """
         return a list of either recently created or recently modified/created contacts
@@ -206,11 +187,11 @@ class ContactsClient(BaseClient):
                 params["vidOffset"] = vid_offset
                 params["timeOffset"] = time_offset
             batch = self._call(
-                "lists/{}/contacts/recent".format(recency_string),
+                f"lists/{recency_string}/contacts/recent",
                 method="GET",
                 params=params,
                 doseq=True,
-                **options
+                **options,
             )
             output.extend([contact for contact in batch["contacts"]])
             finished = not batch["has-more"] or len(output) >= limit
@@ -232,7 +213,7 @@ class ContactsClient(BaseClient):
         limit: int = 100,
         vid_offset: int = 0,
         time_offset: int = 0,
-        **options
+        **options,
     ) -> List[Dict]:
         """
         return contacts in a list
@@ -250,11 +231,11 @@ class ContactsClient(BaseClient):
                 params["vidOffset"] = vid_offset
                 params["timeOffset"] = time_offset
             batch = self._call(
-                "lists/{}/contacts/all".format(list_id),
+                f"lists/{list_id}/contacts/all",
                 method="GET",
                 params=params,
                 doseq=True,
-                **options
+                **options,
             )
             output.extend([contact for contact in batch["contacts"]])
             finished = not batch["has-more"] or len(output) >= limit
@@ -286,7 +267,9 @@ class ContactsClient(BaseClient):
         )
         return self.get_by_email(email, **options)
 
-    def create_or_update_a_contact(self, email: str, data: Dict = None, **options):
+    def create_or_update_a_contact(
+        self, email: str, data: Optional[Dict] = None, **options
+    ):
         warnings.warn(
             "ContactsClient.create_or_update_a_contact is deprecated in favor of "
             "ContactsClient.create_or_update_by_email",
@@ -294,7 +277,7 @@ class ContactsClient(BaseClient):
         )
         return self.create_or_update_by_email(email, data, **options)
 
-    def update(self, contact_id: str, data: Dict = None, **options):
+    def update(self, contact_id: str, data: Optional[Dict] = None, **options):
         warnings.warn(
             "ContactsClient.update is deprecated in favor of "
             "ContactsClient.update_by_id",
@@ -302,7 +285,7 @@ class ContactsClient(BaseClient):
         )
         return self.update_by_id(contact_id, data, **options)
 
-    def update_a_contact(self, contact_id: str, data: Dict = None, **options):
+    def update_a_contact(self, contact_id: str, data: Optional[Dict] = None, **options):
         warnings.warn(
             "ContactsClient.update_a_contact is deprecated in favor of "
             "ContactsClient.update_by_id",
@@ -344,7 +327,7 @@ class ContactsClient(BaseClient):
                 "search/query",
                 method="GET",
                 params={"count": query_limit, "offset": offset, "q": search_query},
-                **options
+                **options,
             )
 
             output += batch["contacts"]
