@@ -1,6 +1,7 @@
 """
 hubspot OAuth2 api
 """
+from typing import Optional
 from urllib.parse import urlencode
 from hubspot3.base import BaseClient
 from hubspot3.utils import get_log
@@ -30,15 +31,15 @@ class OAuth2Client(BaseClient):
         self.access_token = None
 
     def _get_path(self, subpath: str) -> str:
-        return "oauth/v{}/{}".format(OAUTH2_API_VERSION, subpath)
+        return f"oauth/v{OAUTH2_API_VERSION}/{subpath}"
 
     def get_tokens(
         self,
         authorization_code: str,
         redirect_uri: str,
-        client_id: str = None,
-        client_secret: str = None,
-        **options
+        client_id: Optional[str] = None,
+        client_secret: Optional[str] = None,
+        **options,
     ):
         """
         Request an initial token pair using the provided credentials.
@@ -66,10 +67,10 @@ class OAuth2Client(BaseClient):
 
     def refresh_tokens(
         self,
-        client_id: str = None,
-        client_secret: str = None,
-        refresh_token: str = None,
-        **options
+        client_id: Optional[str] = None,
+        client_secret: Optional[str] = None,
+        refresh_token: Optional[str] = None,
+        **options,
     ):
         """
         Request a new token pair using the provided refresh token and credentials.
@@ -100,9 +101,9 @@ class OAuth2Client(BaseClient):
 
         :see: https://developers.hubspot.com/docs/methods/oauth2/get-access-token-information
         """
-        return self._call("access-tokens/{}".format(access_token), **options)
+        return self._call(f"access-tokens/{access_token}", **options)
 
-    def get_refresh_token_data(self, refresh_token: str = None, **options):
+    def get_refresh_token_data(self, refresh_token: Optional[str] = None, **options):
         """
         Get the meta data for a refresh token.
 
@@ -112,10 +113,10 @@ class OAuth2Client(BaseClient):
         :see: https://developers.hubspot.com/docs/methods/oauth2/get-refresh-token-information
         """
         return self._call(
-            "refresh-tokens/{}".format(refresh_token or self.refresh_token), **options
+            f"refresh-tokens/{refresh_token or self.refresh_token}", **options
         )
 
-    def delete_refresh_token(self, refresh_token: str = None):
+    def delete_refresh_token(self, refresh_token: Optional[str] = None):
         """
         Deletes a refresh token. You can use this to delete your refresh token if a user
         uninstalls your app.
@@ -126,6 +127,6 @@ class OAuth2Client(BaseClient):
         :see: https://developers.hubspot.com/docs/methods/oauth2/delete-refresh-token
         """
         return self._call(
-            "refresh-tokens/{}".format(refresh_token or self.refresh_token),
+            f"refresh-tokens/{refresh_token or self.refresh_token}",
             method="DELETE",
         )
