@@ -1,9 +1,9 @@
 """
 hubspot tickets api
 """
+from typing import Dict, List, Optional
 from hubspot3.base import BaseClient
 from hubspot3.utils import get_log
-from typing import Dict, List
 
 
 TICKETS_API_VERSION = "1"
@@ -22,10 +22,10 @@ class TicketsClient(BaseClient):
 
     def _get_path(self, subpath):
         """tickets subpath generator"""
-        return "crm-objects/v{}/{}".format(TICKETS_API_VERSION, subpath)
+        return f"crm-objects/v{TICKETS_API_VERSION}/{subpath}"
 
     def create(
-        self, pipeline: str, stage: str, properties: Dict = None, **options
+        self, pipeline: str, stage: str, properties: Optional[Dict] = None, **options
     ) -> Dict:
         """
         create a ticket.
@@ -49,18 +49,15 @@ class TicketsClient(BaseClient):
         """
         ticket_data = [{"name": x, "value": y} for x, y in data.items()]
         return self._call(
-            "objects/tickets/{}".format(ticket_id),
-            method="PUT",
-            data=ticket_data,
-            **options
+            f"objects/tickets/{ticket_id}", method="PUT", data=ticket_data, **options
         )
 
     def get(
         self,
         ticket_id: str,
-        properties: List[str] = None,
+        properties: Optional[List[str]] = None,
         include_deleted: bool = False,
-        **options
+        **options,
     ) -> Dict:
         """
         get a ticket by its ticket_id
@@ -78,13 +75,15 @@ class TicketsClient(BaseClient):
         options.update({"params": params})
 
         return self._call(
-            "objects/tickets/{}".format(ticket_id),
+            f"objects/tickets/{ticket_id}",
             method="GET",
             properties=properties,
-            **options
+            **options,
         )
 
-    def get_all(self, properties: List[str] = None, limit: int = -1, **options) -> list:
+    def get_all(
+        self, properties: Optional[List[str]] = None, limit: int = -1, **options
+    ) -> list:
         """
         Get all tickets in hubspot
         :see: https://developers.hubspot.com/docs/methods/tickets/get-all-tickets
@@ -106,7 +105,7 @@ class TicketsClient(BaseClient):
                 method="GET",
                 params={"offset": offset},
                 properties=properties,
-                **options
+                **options,
             )
             output.extend(batch["objects"])
             finished = not batch["hasMore"]
